API: `Router`
=============

The main export of this library.

```js
// cjs modules
var Router = require('react-router')

// or global build
var Router = window.ReactRouter

// contains these exports

// methods
Router.run
Router.create

// components
Router.DefaultRoute
Router.Link
Router.NotFoundRoute
Router.Redirect
Router.Route

// mixins
Router.State
Router.Navigation
```

